from .i18n_extension import (
    I18N_EXTENSION_TYPE,
    I18N_GET_LOCALES_PERMISSION_ID,
    I18N_SET_LOCALES_PERMISSION_ID,
    I18nExtension,
)

__all__ = [
    "I18N_EXTENSION_TYPE",
    "I18N_GET_LOCALES_PERMISSION_ID",
    "I18N_SET_LOCALES_PERMISSION_ID",
    "I18nExtension",
]
